package de.intevation.flys.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.GeneratedValue;
import javax.persistence.Column;
import javax.persistence.SequenceGenerator;
import javax.persistence.GenerationType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;

import org.apache.log4j.Logger;


@Entity
@Table(name = "flow_velocity_measure_values")
public class FlowVelocityMeasurementValue
implements   Serializable
{
    private static Logger logger =
        Logger.getLogger(FlowVelocityMeasurementValue.class);


    private Integer id;

    private FlowVelocityMeasurement measurement;

    private BigDecimal station;
    private BigDecimal w;
    private BigDecimal q;
    private BigDecimal v;

    private Date datetime;

    private String description;


    public FlowVelocityMeasurementValue() {
    }


    public FlowVelocityMeasurementValue(
        FlowVelocityMeasurement measurement,
        Date                    datetime,
        BigDecimal              station,
        BigDecimal              w,
        BigDecimal              q,
        BigDecimal              v,
        String                  description
    ) {
        this.measurement = measurement;
        this.datetime    = datetime;
        this.station     = station;
        this.w           = w;
        this.q           = q;
        this.v           = v;
        this.description = description;
    }

    @Id
    @SequenceGenerator(
        name           = "SEQUENCE_FV_MEASURE_VALUES_ID_SEQ",
        sequenceName   = "FV_MEASURE_VALUES_ID_SEQ",
        allocationSize = 1)
    @GeneratedValue(
        strategy  = GenerationType.SEQUENCE,
        generator = "SEQUENCE_FV_MEASURE_VALUES_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "measurements_id")
    public FlowVelocityMeasurement getMeasurement() {
        return measurement;
    }

    public void setMeasurement(FlowVelocityMeasurement measurement) {
        this.measurement = measurement;
    }

    @Column(name = "station")
    public BigDecimal getStation() {
        return station;
    }

    public void setStation(BigDecimal station) {
        this.station = station;
    }

    @Column(name = "datetime")
    public Date getDatetime() {
        return datetime;
    }

    public void setDatetime(Date datetime) {
        this.datetime = datetime;
    }

    @Column(name = "w")
    public BigDecimal getW() {
        return w;
    }

    public void setW(BigDecimal w) {
        this.w = w;
    }

    @Column(name = "q")
    public BigDecimal getQ() {
        return q;
    }

    public void setQ(BigDecimal q) {
        this.q = q;
    }

    @Column(name = "v")
    public BigDecimal getV() {
        return v;
    }

    public void setV(BigDecimal v) {
        this.v = v;
    }

    @Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
